==> vtk6-6.3.0-5-armv6h.pkg.tar.xz: vtk/vtkImageActorPointPlacer.java <==
// java wrapper for vtkImageActorPointPlacer object
//

package vtk;
import vtk.*;

public class vtkImageActorPointPlacer extends vtkPointPlacer
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int ComputeWorldPosition_2(vtkRenderer id0,double id1[],double id2[],double id3[]);
  public int ComputeWorldPosition(vtkRenderer id0,double id1[],double id2[],double id3[])
    { return ComputeWorldPosition_2(id0,id1,id2,id3); }

  private native int ComputeWorldPosition_3(vtkRenderer id0,double id1[],double id2[],double id3[],double id4[]);
  public int ComputeWorldPosition(vtkRenderer id0,double id1[],double id2[],double id3[],double id4[])
    { return ComputeWorldPosition_3(id0,id1,id2,id3,id4); }

  private native int ValidateWorldPosition_4(double id0[]);
  public int ValidateWorldPosition(double id0[])
    { return ValidateWorldPosition_4(id0); }

  private native int ValidateWorldPosition_5(double id0[],double id1[]);
  public int ValidateWorldPosition(double id0[],double id1[])
    { return ValidateWorldPosition_5(id0,id1); }

  private native int UpdateWorldPosition_6(vtkRenderer id0,double id1[],double id2[]);
  public int UpdateWorldPosition(vtkRenderer id0,double id1[],double id2[])
    { return UpdateWorldPosition_6(id0,id1,id2); }

  private native int UpdateInternalState_7();
  public int UpdateInternalState()
    { return UpdateInternalState_7(); }

  private native void SetImageActor_8(vtkImageActor id0);
  public void SetImageActor(vtkImageActor id0)
    { SetImageActor_8(id0); }

  private native long GetImageActor_9();
  public vtkImageActor GetImageActor() {
    long temp = GetImageActor_9();

    if (temp == 0) return null;
    return (vtkImageActor)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetBounds_10(double id0,double id1,double id2,double id3,double id4,double id5);
  public void SetBounds(double id0,double id1,double id2,double id3,double id4,double id5)
    { SetBounds_10(id0,id1,id2,id3,id4,id5); }

  private native void SetBounds_11(double id0[]);
  public void SetBounds(double id0[])
    { SetBounds_11(id0); }

  private native double[] GetBounds_12();
  public double[] GetBounds()
    { return GetBounds_12(); }

  private native void SetWorldTolerance_13(double id0);
  public void SetWorldTolerance(double id0)
    { SetWorldTolerance_13(id0); }

  public vtkImageActorPointPlacer() { super(); }

  public vtkImageActorPointPlacer(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-14-armv6h.pkg.tar.xz: vtk/vtkImageActorPointPlacer.java <==
// java wrapper for vtkImageActorPointPlacer object
//

package vtk;
import vtk.*;

public class vtkImageActorPointPlacer extends vtkPointPlacer
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int ComputeWorldPosition_2(vtkRenderer id0,double id1[],double id2[],double id3[]);
  public int ComputeWorldPosition(vtkRenderer id0,double id1[],double id2[],double id3[])
    { return ComputeWorldPosition_2(id0,id1,id2,id3); }

  private native int ComputeWorldPosition_3(vtkRenderer id0,double id1[],double id2[],double id3[],double id4[]);
  public int ComputeWorldPosition(vtkRenderer id0,double id1[],double id2[],double id3[],double id4[])
    { return ComputeWorldPosition_3(id0,id1,id2,id3,id4); }

  private native int ValidateWorldPosition_4(double id0[]);
  public int ValidateWorldPosition(double id0[])
    { return ValidateWorldPosition_4(id0); }

  private native int ValidateWorldPosition_5(double id0[],double id1[]);
  public int ValidateWorldPosition(double id0[],double id1[])
    { return ValidateWorldPosition_5(id0,id1); }

  private native int UpdateWorldPosition_6(vtkRenderer id0,double id1[],double id2[]);
  public int UpdateWorldPosition(vtkRenderer id0,double id1[],double id2[])
    { return UpdateWorldPosition_6(id0,id1,id2); }

  private native int UpdateInternalState_7();
  public int UpdateInternalState()
    { return UpdateInternalState_7(); }

  private native void SetImageActor_8(vtkImageActor id0);
  public void SetImageActor(vtkImageActor id0)
    { SetImageActor_8(id0); }

  private native long GetImageActor_9();
  public vtkImageActor GetImageActor() {
    long temp = GetImageActor_9();

    if (temp == 0) return null;
    return (vtkImageActor)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetBounds_10(double id0,double id1,double id2,double id3,double id4,double id5);
  public void SetBounds(double id0,double id1,double id2,double id3,double id4,double id5)
    { SetBounds_10(id0,id1,id2,id3,id4,id5); }

  private native void SetBounds_11(double id0[]);
  public void SetBounds(double id0[])
    { SetBounds_11(id0); }

  private native double[] GetBounds_12();
  public double[] GetBounds()
    { return GetBounds_12(); }

  private native void SetWorldTolerance_13(double id0);
  public void SetWorldTolerance(double id0)
    { SetWorldTolerance_13(id0); }

  public vtkImageActorPointPlacer() { super(); }

  public vtkImageActorPointPlacer(long id) { super(id); }
  public native long   VTKInit();

}
